This function convert tracks point as a dataframe into a shapefile.

shapefile_tracks(eDNA_tracks, path_save)

Arguments

eDNA_tracks

A dataframe, the "tracks_good_distance" one obtained with the "spygen_tracks" function.

path_save

A character indicating the path to save data.

Value

Save the shapefile to the path indicated by path_save.