R/01_clean_eDNA_functions.R
convert_to_matrix_function.Rd
This function convert spygen raw data into a site X species matrix.
convert_to_matrix_function(raw_spygen_path)
A character indicating the path of spygen raw data. Data has to be in the format ".xlsx".
A dataframe in the format site X species.