This function convert tracks point as a dataframe into a shapefile.
shapefile_tracks(eDNA_tracks, path_save)A dataframe, the "tracks_good_distance" one obtained with the "spygen_tracks" function.
A character indicating the path to save data.
Save the shapefile to the path indicated by path_save.