This function create a subset of eDNA data by spygen_code.
spygen_subset_function(eDNA_species_data_path, spygen_code_subset)A character indicating the path of cleaned spygen data. Data has to be in the format ".csv".
A character or a dataframe indicating which spygen_code to subset the data with. If supply a dataframe, make sure to name the spygen code column "spygen_code"
A dataframe in the format site X species, subset from eDNA_species_data.